client

package
v0.0.0-...-90c59a5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2018 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// TestNET is waves test
	TestNET = "https://testnet1.wavesnodes.com"
	// MainNET is waves prod
	MainNET = "https://nodes.wavesnodes.com"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AssetsService

type AssetsService struct {
	// contains filtered or unexported fields
}

AssetsService holds sling instance

func NewAssetsService

func NewAssetsService(url string) *AssetsService

NewAssetsService returns a new AccountService.

func (*AssetsService) GetAssetsBalanceAddress

func (s *AssetsService) GetAssetsBalanceAddress(address string) (*model.Assets, *http.Response, error)

GetAssetsBalanceAddress Balances for all assets that the given account ever had (besides WAVES). https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-assetsbalanceaddress

func (*AssetsService) GetAssetsBalanceAddressAssetID

func (s *AssetsService) GetAssetsBalanceAddressAssetID(address, assetID string) (*model.Balances, *http.Response, error)

GetAssetsBalanceAddressAssetID Account's balance for the given asset. https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-assetsbalanceaddressassetid

type BlocksService

type BlocksService struct {
	// contains filtered or unexported fields
}

TransactionsService holds sling instance

func NewBlocksService

func NewBlocksService(url string) *BlocksService

NewTransactionsService returns a new AccountService.

func NewBlocksServiceTest

func NewBlocksServiceTest() *BlocksService

NewTransactionsServiceTest returns a new AccountService.

func (*BlocksService) GetBlocksAtHeight

func (s *BlocksService) GetBlocksAtHeight(Height int64) (*model.Blocks, *http.Response, error)

GetBlocksAtHeight Return block data at the given height https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-blocksatheight

func (*BlocksService) GetBlocksAtHeightDefaultClient

func (s *BlocksService) GetBlocksAtHeightDefaultClient(Height int64) (*model.Blocks, *http.Response, error)

func (*BlocksService) GetBlocksLast

func (s *BlocksService) GetBlocksLast() (*model.Blocks, *http.Response, error)

GetBlocksSeqFromTo Return block data at the given height range https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-blocksseqfromto

func (*BlocksService) GetBlocksSeqFromTo

func (s *BlocksService) GetBlocksSeqFromTo(from, to int64) (*[]model.Blocks, *http.Response, error)

GetBlocksSeqFromTo Return block data at the given height range https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-blocksseqfromto

type TransactionsService

type TransactionsService struct {
	// contains filtered or unexported fields
}

TransactionsService holds sling instance

func NewTransactionsService

func NewTransactionsService(url string) *TransactionsService

NewTransactionsService returns a new AccountService.

func (*TransactionsService) GetTransactionsInfoID

func (s *TransactionsService) GetTransactionsInfoID(ID string) (*model.Transactions, *http.Response, error)

GetTransactionsInfoID Return transaction data by transaction ID https://github.com/wavesplatform/Waves/wiki/Waves-Node-REST-API#get-transactionsinfoid

Jump to